@@ -277,7 +277,7 @@ void startJob() {
   String sSrc = le_source.text();
   KURL src = new KURL( new KURL(sCurrent), sSrc );
 
-  if ( src.isMalformed() ) {
+  if ( !src.isValid() ) {
     QMessageBox.critical(this, "Kioslave Error Message", "Source URL is malformed" );
     return;
   }
@@ -285,7 +285,7 @@ void startJob() {
   String sDest = le_dest.text();
   KURL dest = new KURL( new KURL(sCurrent), sDest );
 
-  if ( dest.isMalformed() &&
+  if ( !dest.isValid() &&
        ( selectedOperation == Copy || selectedOperation == Move ) ) {
     QMessageBox.critical(this, "Kioslave Error Message",
                        "Destination URL is malformed" );
@@ -524,7 +524,7 @@ static String[][] options =
 };
 
 public static void main(String[] argv) {
-  KCmdLineArgs.init( argv, "kioslavetest", description, version );
+  KCmdLineArgs.init( argv, "kioslavetest", "KIOSlaveTest", description, version );
   KCmdLineArgs.addCmdLineOptions( options );
   KApplication app = new KApplication();
 
