@@ -5,7 +5,7 @@ public class KillerFilter extends QObject {
 	public boolean eventFilter( QObject object, QEvent event) {
 		if (event.type() == QEvent.MouseButtonPress) {
 			if ( ((QMouseEvent)event).button() == RightButton ) {
-				((QWidget) object).close(true);
+				((QWidget) object).close();
 				return true;
 			} else {
 				return false;
